from songshare.models import Sound, Comment, Notes, Rhythm, AudioTrack, SynthTrack, Band, CompleteSet
from django.http import HttpResponse
from django.core import serializers
from django.shortcuts import get_object_or_404
import logging
from django.views.decorators.csrf import csrf_exempt
import datetime
from django.conf import settings

logger = logging.getLogger(__name__)

##########
# sounds (audio recording)
##########
def sounds(request):
    sounds = Sound.objects.all().order_by('-pub_date')
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(sounds, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

@csrf_exempt
def sound(request, sound_id=None):
    if request.POST:
        sound = Sound(name=request.POST["name"],
                      description=request.POST["description"],
                      udid=request.POST["udid"],
                      lat=request.POST["lat"],
                      long=request.POST["long"],
                      pub_date=datetime.datetime.now(),
                      likes=0)
        file = request.FILES["soundfile"]
        sound.path = file.name
        destination = open(settings.MEDIA_ROOT + file.name, 'wb+')
        for chunk in file.chunks():
            destination.write(chunk)
    destination.close()
    sound.save()
    logging.debug("this is the sound id: %d", sound.id)
    sound_id = sound.id
    sound = Sound.objects.filter(id=sound_id)
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(sound, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

##########
# notes (synth recording)
##########
def notes(request):
    notes = Notes.objects.all().order_by('-pub_date')
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(notes, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

@csrf_exempt
def note(request, note_id=None):
    if request.POST:
        note = Notes(name=request.POST["name"],
                     description=request.POST["description"],
                     udid=request.POST["udid"],
                     lat=request.POST["lat"],
                     long=request.POST["long"],
                     pub_date=datetime.datetime.now(),
                     likes=0)
        file = request.FILES["notefile"]
        note.path = file.name
        destination = open(settings.MEDIA_ROOT + file.name, 'wb+')
        for chunk in file.chunks():
            destination.write(chunk)
        destination.close()
        note.save()
        logging.debug("this is the notes id: %d", note.id)
        note_id = note.id
    notes = Notes.objects.filter(id=note_id)
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(note, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

##########
# rhythms (articulation recording)
##########
def rhythms(request):
    rhythms = Rhythm.objects.all().order_by('-pub_date')
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(rhythms, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

@csrf_exempt
def rhythm(request, note_id=None):
    if request.POST:
        rhythm = Rhythm(name=request.POST["name"],
                        description=request.POST["description"],
                        udid=request.POST["udid"],
                        lat=request.POST["lat"],
                        long=request.POST["long"],
                        pub_date=datetime.datetime.now(),
                        likes=0)
        file = request.FILES["rhythmfile"]
        rhythm.path = file.name
        destination = open(settings.MEDIA_ROOT + file.name, 'wb+')
        for chunk in file.chunks():
            destination.write(chunk)
        destination.close()
        rhythm.save()
        logging.debug("this is the rhythm id: %d", rhythm.id)
        rhythm_id = rhythm.id
    rhythm = Rhythm.objects.filter(id=rhythm_id)
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(rhythm, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

##########
# audio track
##########
def audiotracks(request):
    audiotracks = AudioTrack.objects.all().order_by('-pub_date')
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(audiotracks, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

@csrf_exempt
def audiotrack(request, audiotrack_id=None):
    if request.POST:
        audiotrack = AudioTrack(name=request.POST["name"],
                                description=request.POST["description"],
                                udid=request.POST["udid"],
                                lat=request.POST["lat"],
                                long=request.POST["long"],
                                pub_date=datetime.datetime.now(),
                                likes=0)
        soundfile=request.FILES["soundfile"]
        audiotrack.soundpath = soundfile.name
        destination = open(settings.MEDIA_ROOT + soundfile.name, 'wb+')
        for chunk in soundfile.chunks():
            destination.write(chunk)
        destination.close()
        artfile=request.FILES["artfile"]
        audiotrack.artpath = artfile.name
        destination = open(settings.MEDIA_ROOT + artfile.name, 'wb+')
        for chunk in artfile.chunks():	
            destination.write(chunk)
        destination.close()
        audiotrack.save()
        logging.debug("this is the audiotrack id: %d", audiotrack.id)
        audiotrack_id = audiotrack.id
    audiotrack = AudioTrack.objects.filter(id=audiotrack_id)
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(audiotrack, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

##########
# synth track
##########
def synthtracks(request):
    synthtracks = SynthTrack.objects.all().order_by('-pub_date')
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(synthtracks, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

@csrf_exempt
def synthtrack(request, synthtrack_id=None):
    if request.POST:
        synthtrack = SynthTrack(name=request.POST["name"],
                                description=request.POST["description"],
                                udid=request.POST["udid"],
                                lat=request.POST["lat"],
                                long=request.POST["long"],
                                pub_date=datetime.datetime.now(),
                                likes=0)
        notefile=request.FILES["notefile"]
        synthtrack.notepath = notefile.name
        destination = open(settings.MEDIA_ROOT + notefile.name, 'wb+')
        for chunk in notefile.chunks():
            destination.write(chunk)
        destination.close()
        artfile=request.FILES["artfile"]
        synthtrack.artpath = artfile.name
        destination = open(settings.MEDIA_ROOT + artfile.name, 'wb+')
        for chunk in artfile.chunks():	
            destination.write(chunk)
        destination.close()
        synthtrack.save()
        logging.debug("this is the synthtrack id: %d", synthtrack.id)
        synthtrack_id = synthtrack.id
    synthtrack = SynthTrack.objects.filter(id=synthtrack_id)
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(synthtrack, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

##########
# whole band
##########
def bands(request):
    bands = Band.objects.all().order_by('-pub_date')
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(bands, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")
@csrf_exempt
def band(request, band_id=None):
    if request.POST:
        band = Band(name=request.POST["name"],
                                description=request.POST["description"],
                                udid=request.POST["udid"],
                                lat=request.POST["lat"],
                                long=request.POST["long"],
                                pub_date=datetime.datetime.now(),
                                likes=0)
        chordfile=request.FILES["chordfile"]
        band.chordpath = chordfile.name
        destination = open(settings.MEDIA_ROOT + chordfile.name, 'wb+')
        for chunk in chordfile.chunks():
            destination.write(chunk)
        destination.close()
        bassfile=request.FILES["bassfile"]
        band.basspath = bassfile.name
        destination = open(settings.MEDIA_ROOT + bassfile.name, 'wb+')
        for chunk in bassfile.chunks():	
            destination.write(chunk)
        destination.close()
        leadfile=request.FILES["leadfile"]
        band.leadpath = leadfile.name
        destination = open(settings.MEDIA_ROOT + leadfile.name, 'wb+')
        for chunk in leadfile.chunks():	
            destination.write(chunk)
        destination.close()
        audio1file=request.FILES["audio1file"]
        band.audio1path = audio1file.name
        destination = open(settings.MEDIA_ROOT + audio1file.name, 'wb+')
        for chunk in audio1file.chunks():	
            destination.write(chunk)
        destination.close()
        audio2file=request.FILES["audio2file"]
        band.audio2path = audio2file.name
        destination = open(settings.MEDIA_ROOT + audio2file.name, 'wb+')
        for chunk in audio2file.chunks():	
            destination.write(chunk)
        destination.close()

        artchordfile=request.FILES["artchordfile"]
        band.artchordpath = artchordfile.name
        destination = open(settings.MEDIA_ROOT + artchordfile.name, 'wb+')
        for chunk in artchordfile.chunks():	
            destination.write(chunk)
        destination.close()
        artbassfile=request.FILES["artbassfile"]
        band.artbasspath = artbassfile.name
        destination = open(settings.MEDIA_ROOT + artbassfile.name, 'wb+')
        for chunk in artbassfile.chunks():	
            destination.write(chunk)
        destination.close()
        artleadfile=request.FILES["artleadfile"]
        band.artleadpath = artleadfile.name
        destination = open(settings.MEDIA_ROOT + artleadfile.name, 'wb+')
        for chunk in artleadfile.chunks():	
            destination.write(chunk)
        destination.close()
        artaudio1file=request.FILES["artaudio1file"]
        band.artaudio1path = artaudio1file.name
        destination = open(settings.MEDIA_ROOT + artaudio1file.name, 'wb+')
        for chunk in artaudio1file.chunks():	
            destination.write(chunk)
        destination.close()
        artaudio2file=request.FILES["artaudio2file"]
        band.artaudio2path = artaudio2file.name
        destination = open(settings.MEDIA_ROOT + artaudio2file.name, 'wb+')
        for chunk in artaudio2file.chunks():	
            destination.write(chunk)
        destination.close()

        band.save()
        logging.debug("this is the band id: %d", band.id)
        band_id = band.id
    band = Band.objects.filter(id=band_id)
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(band, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

##########
# set
##########
def completesets(request):
    completesets = CompleteSet.objects.all().order_by('-pub_date')
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(completesets, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")

@csrf_exempt
def completeset(request, completeset_id=None):
    if request.POST:
        completeset = CompleteSet(name=request.POST["name"],
                                description=request.POST["description"],
                                udid=request.POST["udid"],
                                lat=request.POST["lat"],
                                long=request.POST["long"],
                                pub_date=datetime.datetime.now(),
                                likes=0)
        chordsfile=request.FILES["chordsfile"]
        completeset.chordspath = chordsfile.name
        destination = open(settings.MEDIA_ROOT + chordsfile.name, 'wb+')
        for chunk in chordsfile.chunks():	
            destination.write(chunk)
        destination.close()
        artchordsfile=request.FILES["artchordsfile"]
        completeset.artchordspath = artchordsfile.name
        destination = open(settings.MEDIA_ROOT + artchordsfile.name, 'wb+')
        for chunk in artchordsfile.chunks():	
            destination.write(chunk)
        destination.close()
        completeset.save()
        logging.debug("this is the set id: %d", completeset.id)
        completeset_id = completeset.id
    completeset = CompleteSet.objects.filter(id=completeset_id)
    json_serializer = serializers.get_serializer("json")()
    output = json_serializer.serialize(completeset, ensure_ascii=False)
    return HttpResponse(output, content_type="application/json")